@@ -1,5 +1,3 @@
-(* included: type.ml *)
-
 let hex n =
   Char.chr (
     if n < 10 then n + 48
@@ -53,26 +51,12 @@ let json_string_of_string s =
   write_string ob s;
   Buffer.contents ob
 
-let test_string () =
-  let s = Bytes.create 256 in
-  for i = 0 to 255 do
-    Bytes.set s i (Char.chr i)
-  done;
-  json_string_of_string (Bytes.to_string s)
-
-
 let write_null ob () =
   Buffer.add_string ob "null"
 
 let write_bool ob x =
   Buffer.add_string ob (if x then "true" else "false")
 
-
-let max_digits =
-  max
-    (String.length (string_of_int max_int))
-    (String.length (string_of_int min_int))
-
 let dec n =
   Char.chr (n + 48)
 
@@ -179,9 +163,9 @@ let json_string_of_float x =
 let write_std_float ob x =
   match classify_float x with
     FP_nan ->
-      json_error "NaN value not allowed in standard JSON"
+      Common.json_error "NaN value not allowed in standard JSON"
   | FP_infinite ->
-      json_error
+      Common.json_error
         (if x > 0. then
            "Infinity value not allowed in standard JSON"
          else
@@ -200,9 +184,9 @@ let write_std_float ob x =
 let write_std_float_prec significant_figures ob x =
   match classify_float x with
     FP_nan ->
-      json_error "NaN value not allowed in standard JSON"
+      Common.json_error "NaN value not allowed in standard JSON"
   | FP_infinite ->
-      json_error
+      Common.json_error
         (if x > 0. then
            "Infinity value not allowed in standard JSON"
          else
@@ -216,26 +200,6 @@ let std_json_string_of_float x =
   Buffer.contents ob
 
 
-let test_float () =
-  let l = [ 0.; 1.; -1. ] in
-  let l = l @ List.map (fun x -> 2. *. x +. 1.) l in
-  let l = l @ List.map (fun x -> x /. sqrt 2.) l in
-  let l = l @ List.map (fun x -> x *. sqrt 3.) l in
-  let l = l @ List.map cos l in
-  let l = l @ List.map (fun x -> x *. 1.23e50) l in
-  let l = l @ [ infinity; neg_infinity ] in
-  List.iter (
-    fun x ->
-      let s = Printf.sprintf "%.17g" x in
-      let y = float_of_string s in
-      Printf.printf "%g %g %S %B\n" x y s (x = y)
-  )
-    l
-
-(*
-let () = test_float ()
-*)
-
 let write_intlit = Buffer.add_string
 let write_floatlit = Buffer.add_string
 let write_stringlit = Buffer.add_string
@@ -425,7 +389,11 @@ let to_output ?buf ?(len=4096) ?(suf = "") ?std out x =
       | Some ob -> Buffer.clear ob; ob
   in
   to_buffer ~suf ?std ob x;
-  out#output (Buffer.contents ob) 0 (Buffer.length ob);
+  (* this requires an int and never uses it. This is done to preserve
+     backward compatibility to not break the signatur but can safely
+     be changed to require unit in a future compatibility-breaking
+     release *)
+  let _ : int = out#output (Buffer.contents ob) 0 (Buffer.length ob) in
   Buffer.clear ob
 
 let to_file ?len ?std ?(suf = "\n") file x =
